cpp <-
function(fit)
 {
  ## estimate p(x|y) with a Dirichlet
  ## multinomial fitted using sampled theta's
  ##
  ## fit    result of running MCMC in double-overdispersion model

  ## WTcounts vector holding experimental CDR3 sequence counts, Wild Type cells
  wt <- fit$counts[[1]] + fit$counts[[2]]  ## add SC and MC WT counts, per subject
  WTcounts <- apply(wt,1,sum)  ## sum over subjects

  theta.mean <- apply( fit$thetasave, 2, mean )
  theta.v <- var( fit$thetasave )
  dirtot <- median(   theta.mean*(1-theta.mean)/diag(theta.v) - 1 ) 

  # next compute the conditional p-value by simulating Dirichlet multinomial
  # WT counts

  xstar <- apply( fit$thetasave, 1, rmultinom, n=1, size=sum(WTcounts) )

  # predicted data density
  logpred.star <- lgamma( xstar + dirtot*theta.mean ) - lgamma( xstar+1 )

  # observed data density
  logpred.x <- lgamma( WTcounts + dirtot*theta.mean ) - lgamma( WTcounts + 1 )

  logpred.ratio <- apply( logpred.star - logpred.x , 2, sum )

  pval <- mean( logpred.ratio <= 0 )

  return(pval)
  }

