simdod <-
function(nsim,theta,phi, sizes, mcmc )
 {
  ##############################################################################
  ## simulate the double overdispersion model in Pei et al 2012 and compute CPP
  ## for each data set
  ##
  ## nsim     number of simulated data sets
  ## theta    latent frequency of proportions (vector over CDR3 types)
  ## phi      overdispersion parameter for in vitro growth
  ##
  ## sizes$n.wtsc vector (number of subjects) holding# WTSC sequences per subject
  ## sizes$n.wtmc vector (number of subjects) holding# WTMC sequences per subject
  ## sizes$n.mtsc   vector (number of subjects) holding #MTSC sequences per subject
  ## sizes$n.mtmc   vector (number of subjects) holding #MTMC sequences per subject
  ## sizes$nsurvive   vector (number of subjects) # surviving cells per subject
  ##                          ## for MT MC part
  ##
  ## mcmc$nsave       # stored states in MCMC
  ## mcmc$nskip       # skipped states in MCMC
  ## mcmc$initc       # burn-in
  ## mcmc$phi.init    # initial value
  ## mcmc$phi.delta   # MH windo size

  pval <- numeric(nsim)

  for( isim in 1:nsim )
   {
    # make WT data
    wtsc <- sapply( as.list(sizes$n.wtsc), rmultinom, n=1, prob=theta )
    wtmc <- sapply( as.list(sizes$n.wtmc), rmultinom, n=1, prob=theta )
  
    # make MT SC data
    mtsc <- sapply( as.list(sizes$n.mtsc), rmultinom, n=1, prob=theta )
    # make MT MC data by first getting latent Z's
    muz <- theta %o% sizes$nsurvive
    zstate <- apply(muz,2,rpois, n=nrow(muz) )
    # next make Dirichlet distributed prob vector
    uu <- apply(phi*zstate,2,rgamma,n=nrow(muz) )
    uprob <- t( t(uu)/apply(uu,2,sum) )
    # next make the conditionally multinomial observations
    uplist <- as.list( data.frame(uprob) )  ## columns entries of list
    mtmc <-mapply( function(x,y) rmultinom(n=1,size=x,prob=y), sizes$n.mtmc, uplist )
    simcounts <- list( 'WT-SC'=wtsc, 'WT-MC'=wtmc, 
		'MT-SC'=mtsc, 'MT-MC'=mtmc ) ## simulated data

    # run MCMC  to get posterior of theta given MT (only) data Y=y

    fit.sim <- MCMC( simcounts, sizes$nsurvive, mcmc=mcmc,  method=1,
	print.iter=FALSE)

    ## get conditional predictive p-value

    pval[isim] <- cpp( fit.sim )

    print(isim)
   }
  return( pval )
 }

