
# Code to draw version of Figure S1 in Pei et al 2012
## (1st Figure in supplementary material)

## pull in data
data(patients)
counts <- patients$Vcounts

## collapse over patients
wt <- apply( counts$`WT-SC` + counts$`WT-MC`, 1, sum )
mtsc <- apply( counts$`MT-SC` , 1, sum )
mtmc <- apply( counts$`MT-MC` , 1, sum )

types <- dimnames( counts[[1]] )[[1]]

## pull in MCMC results

data(precooked)
theta <- precooked$fitV$thetasave

## re-arrange types according to posterior median frequency
pmed <- apply( theta, 2, median )
ord <- order(-pmed)

theta.ord <- theta[,ord]
wt.ord <- wt[ord]
mtsc.ord <- mtsc[ord]
mtmc.ord <- mtmc[ord]
types.ord <- types[ord]


## Make picture
pdf( file="figS1.pdf", height=8, width=6 )

## boxplot of theta's

op <- par(mar = c(5,7,2,2) + 0.1)
boxplot(theta.ord, axes=FALSE,space=0.5,horizontal = TRUE,ylim=c(0,0.16), 
     cex=1.5,lwd=1,font=2,cex.axis=1.4,outline=FALSE,boxwex=0.27,  col="grey", 
     yaxs="i")
axis(1, at = seq(0,0.16,by=0.05), labels = seq(0,0.16,by=0.05), cex.axis = 1.5)
axis(2, at = 1:length(types.ord), labels = types.ord, cex.axis = .8,las=1 )
title(ylab = "V region type",cex.lab = 1.4,line = 4.5)
title( xlab="Proportion of CDR-3 sequences",cex.lab = 1.4)

## guide lines
u <- seq(0,.25, by=.025 )
for( i in u )
 { abline( v=i, col="lightgrey" ) }


## proportions for WT, MTSC, MTMC

p1=wt.ord/sum(wt.ord)
p2=mtsc.ord/sum(mtsc.ord)
p3=mtmc.ord/sum(mtmc.ord)
eps <- .06
for(i in 1:length(types) )
{
 rect(0,i-0.25+eps,p1[i],i-0.35+eps,col="blue", border="blue", lwd=1 )
 rect(0,i-0.35+eps,p2[i],i-0.45+eps,col="green", border="green", lwd=1 )
 rect(0,i-0.45+eps,p3[i],i-0.55+eps,col="red", border="red", lwd=1 )
}

box()
## Legend
temp <- legend("topright", legend = c(" ", " "," "),
               text.width = strwidth("MT MC cells"),
               lty=c(1,1,1),lwd=4,cex=1.5,col= c("blue","green","red") ,
               xjust = 1, yjust = 1,bg="white")
text(temp$rect$left + temp$rect$w, temp$text$y,
     c("WT", "MT SC", "MT MC"), cex=1.2,pos=2)

dev.off()
