
## compute approximate likelihood ratio statistic; J region

data(precooked)
## approximate MLE's under alternative
thetaMT.alt <- apply( precooked$fitJ$thetasave, 2, mean )  ## posterior mean 
phi.alt <- mean( precooked$fitJ$phisave )

data(patients)
counts <- patients$Jcounts  ## sequence type counts
nsurvive <- patients$nsurvive  ## surviving cell counts

tmp <- apply( counts$"WT-MC", 1, sum ) + apply( counts$"WT-SC", 1, sum )
thetaWT.alt <- tmp/sum(tmp)  ## MLE

## get null estimates from full MCMC on all data
fitJ <- precooked$fitfull$fitJ.full
theta.null <- apply( fitJ$thetasave, 2, mean )
phi.null <- mean( fitJ$phisave )

## Next I need some sampling to approximate marginal likelihood by
## averaging over simulated Z's ~ poisson prior

zsamp <- function(nsurvive, theta)
	{
	# A poisson sampling function (samples numbers of TG surviving cells)
	mu <- c( theta %o% nsurvive )
	z <- rpois(length(mu), mu) 
	zm <- matrix(z, length(theta), length(nsurvive) )
	zm
	}

## next I need a function that computes the Dirichlet Multinomial
## log likelihood contribution from sampled Z's

lpygz <- function(y,z,phi)
	{
	# y and z count matrices of same size; phi an overdispersion param
	# computed Dirichlet multinomial mass function [eq 3.2, Q et al]
	fee <- ( lgamma( phi*z + y ) - lgamma( y+1 ) - lgamma( phi*z ) )
        fee[y==0 & z==0] <- 0  ## log 1 = log P(y|z)
        fee[y>0 & z==0] <- -Inf  ## not possible
	ny <- apply(y,2,sum)
	nz <- apply(z,2,sum)
	bar <- sum( lgamma(ny+1) + lgamma( phi*nz ) - lgamma(ny+phi*nz) )
	lp <- bar + sum(fee)
	lp
	}

## next I need to perform sampling over Z's and approximate LR stat 
## components

B <- 10000
logpygz.alt <- numeric(B)
logpygz.null <- numeric(B)
for( b in 1:B )
 {
   Z <- zsamp( nsurvive, thetaMT.alt )
   logpygz.alt[b] <- lpygz( counts$"MT-MC", Z, phi.alt )

   Z <- zsamp( nsurvive, theta.null)
   logpygz.null[b] <- lpygz( counts$"MT-MC" , Z, phi.null )
 }
## logsum exp trick
lm.alt <- max( logpygz.alt )
lm.null <- max( logpygz.null )
logpy.alt <- lm.alt + mean( exp( logpygz.alt - lm.alt ) )
logpy.null <- lm.null + mean( exp( logpygz.null - lm.null ) )

## incorporate the other count data...(multinomial)
xWT <- apply( counts$"WT-SC" + counts$"WT-MC",  1, sum )
xMT <- apply( counts$"MT-SC", 1, sum )
nWT <- sum(xWT)
nMT <- sum(xMT)

logpx.alt <-  lgamma(nWT+1)  - sum( lgamma(xWT+1) ) +
		sum( xWT*log( thetaWT.alt ) ) +
		sum( (nWT-xWT)*log( 1-thetaWT.alt ) )+
	      lgamma(nMT+1) - sum( lgamma(xMT+1) ) + 
		sum( xMT*log( thetaMT.alt ) ) + 
		sum( (nMT-xMT)*log( 1-thetaMT.alt ) )

logpx.null <-  lgamma(nWT+1)  - sum( lgamma(xWT+1) ) +
		sum( xWT*log( theta.null) ) +
		sum( (nWT-xWT)*log( 1-theta.null) )+
	      lgamma(nMT+1) - sum( lgamma(xMT+1) ) + 
		sum( xMT*log( theta.null ) ) + 
		sum( (nMT-xMT)*log( 1-theta.null ) )

lrstat <- -2*( logpx.null + logpy.null - logpx.alt - logpy.alt )

## pchisq( lrstat, df=12, lower.tail=FALSE )
## 0.0485251   ### using B=10000
