\name{MCMC}
\alias{MCMC}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Function to run Markov chain Monte Carlo in double overdispserion (DOD) 
 model described in Pei et al. 2012.
}
\description{
 Code samples the posterior distribution of unkown objects given count data,
 under a null hypothesis that all counts have the same mean vector `theta'.
 Unknowns include theta, latent counts Z, and an overdispersion parameter phi; 
 theta is updated by Gibbs sampling; phi and Z are updated by local Metropolis
 Hastings proposals.  Output is relevant to computing a predictive p-value
 testing the null hypothesis.
}
\usage{
MCMC(counts, nsurvive, mcmc = list(nsave = 1000, nskip = 1000, initc = 1000, phi.init = 1, phi.delta = 0.1), method = 1, print.iter = TRUE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{counts}{
A list with four components WT-SC, WT-MC, MT-SC, and MT-MC, 
 all count matrices the same 
 dimension representing frequency counts of sequences from wild-type (WT) cells,
 mutant cells (MT) derived either from single-cell (SC) isolates or in mass-culture
 (MC) conditions.  Each row of each matrix is one sequence type.  Columns
 hold separate data from each subject in the study.
}
  \item{nsurvive}{
Vector (over subjects) holding numbers of surviving cells in in vitro growth
 experiment (for MT-MC data).
}
  \item{mcmc}{
A list holding components for the Markov chain sample structure: nsave (number of saved states), nskip (number of skips between saves), initc (burn in), phi.init (initial
 value of phi parameter), phi.delta (size of MH window, phi parameter).
}
  \item{method}{
1 (condition only on MT data), 2 (condition on all MT and WT data) (method 1 is
 suitable for conditional predictive p-value computation)
}
  \item{print.iter}{
Should an MCMC iteration counter be printed
}
}
\details{
%%  ~~ If necessary, more details than the description above ~~
}
\value{
  \item{zsave}{matrix of saved latent states Z}
  \item{thetasave}{matrix of saved theta vectors}
  \item{phisave}{Saved values of phi}
  \item{counts}{recap of input data}
  \item{nsurvive}{recap of input cell states}
  \item{acrate}{Acceptance rates of two Metropolis Hastings components}
}
\references{
Details in Pei et al., 2012. A conditional predictive p-value to compare a 
 multinomial with an overdispersed multinomial in the analysis of T-cell
 populations. Technical Report \#227, Department of Biostatistics and 
 Medical Informatics, University of Wisconsin, Madison.
}
\author{
Michael A. Newton and Qinglin Pei. 
}

\examples{

data(patients)
counts <- patients$Jcounts
nsurvive <- patients$nsurvive

# test on Zuleger et al's 2011 melanoma patient data, J region, CDR3

fit <- MCMC( counts, nsurvive, mcmc=list( nsave=100, nskip=10, initc=10,
		phi.init=1, phi.delta=0.1 ) )

##Note: run the above  much longer for reliable posterior samples (see below
## and results in data(precooked)

# look at output
plot( fit$phisave, type="l" )


### Production runs; (not run here [time consuming] but see results in `precooked')
## MCMC settings adjusted after some preliminary runs to these values
#mcmc <- list(nsave = 10000, nskip = 500, initc = 500, phi.init = 1, phi.delta =0.05)
#fitJ <- MCMC( patients$Jcounts, patients$nsurvive, print.iter=FALSE, mcmc=mcmc )
#fitV <- MCMC( patients$Vcounts, patients$nsurvive, print.iter=FALSE, mcmc=mcmc )

}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ ~kwd1 }
\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
