\name{patients}
\alias{patients}
\docType{data}
\title{
T-cell receptor sequence data from melanoma patients
}
\description{
Peripheral blood from six melanoma patients were assayed for the primary
sequence of the hyper-variable region of the T-cell receptor.  Data record
sequences from untreated (wild-type WT) cells, and cells selected to have
a mutation (MT) in the HPRT locus.  Data were obtained by two protocols, one
involving single-cell isolates (SC), and one involving mass culture (MC) conditions.
Data are also tabulated at the level of  two receptor properties: J-region type
and V-region type.  MC conditions create extra-multinomial variation under the
null hypothesis of no MT/WT effect
}
\usage{data(patients)}
\format{
  patients is a list with three entries; Jcounts, Vcounts, and nsurvive.
  Jcounts and Vcounts are structured similarly; each 
  is a list with four data matrices, each matrix is number of types
 times number of patients, and entries count how many T-cell receptor sequences
 from that patient had that type, when measured by that protocol. The
 four protocols cross two cell types (MT and WT) with two measurement methods
 (SC and MC). 
}
\details{
nsurvive records estimated numbers of surviving cells after treatment to obtain 
 MT cells in the mass culture (MC) conditions
}
\source{
Pei et al. 2012. A conditional predictive p-value to compare a multinomial
with an overdispersed multinomial in the analysis of T-cell populations.
Technical Report \# 227, Department of Biostatistics and Medical Informatics,
University of Wisconsin, Madison.
}
\references{

Zuleger, C.L., Macklin, M.D., Bostwick, B.L., Pei, Q., Newton, M.A., and Albertini, M.R. (2011). In vivo 6-thioguanine-resistant T cells from melanoma patients have public TCR and share TCR beta amino acid sequences with melanoma-reactive T cells. Journal of Immunological Methods, 365, 76-86.
}
\examples{
data(patients)

## look at Fisher p-value ignoring overdispersion
J <- patients$Jcounts
V <- patients$Vcounts

J.WT <- apply( J$"WT-SC" + J$"WT-MC", 1, sum )
J.MT <- apply( J$"MT-SC" + J$"MT-SC", 1, sum )
Jtab <- as.table( cbind( J.WT, J.MT ) )

J.ft <- fisher.test( Jtab, hybrid=TRUE  )
 ## p = 0.000961

V.WT <- apply( V$"WT-SC" + V$"WT-MC", 1, sum )
V.MT <- apply( V$"MT-SC" + V$"MT-SC", 1, sum )
Vtab <- as.table( cbind( V.WT, V.MT ) )

V.ft <- fisher.test( Vtab, hybrid=TRUE  )
 ## p < 2.2e-16

}
\keyword{datasets}
