\name{powdod}
\alias{powdod}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Function to simulate the distribution of the 
conditinal predictive p-value in the double-overdispersion
 model of Pei et al. 2012. (works for power calculation)
}
\description{
Takes parameter settings and a data structure and simulates count data from the double overdispersion model, runs MCMC on each data set, and computes the conditional predictive
p-value on each data set.
}
\usage{
powdod(nsim, thetaWT, thetaMT, phi, sizes, mcmc)
}
\arguments{
  \item{nsim}{ number of simulated data sets } 
  \item{thetaWT}{ underlying vector of type frequencies; WT }
  \item{thetaMT}{ underlying vector of type frequencies; MT }
  \item{phi}{ underlying overdispersion parameter for in-vitro growth phase }
  \item{sizes}{ amount of sequencing of for each patient and each protocol }
  \item{mcmc}{ specifications of the MCMC run on each data set }
}
\value{
A random sample from the distribution of the conditional predictive p-value;
on the alternative hypothesis if thetaMT != thetaWT
}
\references{
Details in Pei et al., 2012. A conditional predictive p-value to compare a
 multinomial with an overdispersed multinomial in the analysis of T-cell
 populations. Technical Report \#227, Department of Biostatistics and
 Medical Informatics, University of Wisconsin, Madison.

}
\author{
Michael A. Newton
}

\examples{

data(patients)
counts <- patients$Jcounts
nsurvive <- patients$nsurvive

pow <- powdod( nsim=5, thetaWT=rep(1/13,13), 
   	thetaMT=c( 1/5, 1/5, rep( 3/(5*11), 11) ), phi=.2,
        sizes=list( n.wtsc = apply(counts$`WT-SC`,2,sum),
                    n.wtmc = apply(counts$`WT-MC`,2,sum),
                    n.mtmc = apply(counts$`MT-MC`,2,sum),
                    n.mtsc = apply(counts$`MT-SC`,2,sum),
                    nsurvive = nsurvive  ) ,
        mcmc=list( phi.init=1, phi.delta=.1, nsave=10, nskip=10, initc=2 ) )


## Results of a longer chain, using ML alternative estimated
## thetaMT and thetaWT  are computed by "demo(power)"


}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ ~kwd1 }
\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
