\name{simdod}
\alias{simdod}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Function to simulate the null distribution of the 
conditinal predictive p-value in the double-overdispersion
 model of Pei et al. 2012.
}
\description{
Takes parameter settings and a data structure and simulates count data from the double overdispersion model, runs MCMC on each data set, and computes the conditional predictive
p-value on each data set.
}
\usage{
simdod(nsim, theta, phi, sizes, mcmc)
}
\arguments{
  \item{nsim}{ number of simulated data sets } 
  \item{theta}{ underlying vector of type frequencies }
  \item{phi}{ underlying overdispersion parameter for in-vitro growth phase }
  \item{sizes}{ amount of sequencing of for each patient and each protocol }
  \item{mcmc}{ specifications of the MCMC run on each data set }
}
\value{
A random sample from the null distribution of the conditional predictive p-value
}
\references{
Details in Pei et al., 2012. A conditional predictive p-value to compare a
 multinomial with an overdispersed multinomial in the analysis of T-cell
 populations. Technical Report \#227, Department of Biostatistics and
 Medical Informatics, University of Wisconsin, Madison.

}
\author{
Michael A. Newton
}

\examples{

data(patients)
counts <- patients$Jcounts
nsurvive <- patients$nsurvive

sim <- simdod( nsim=5, theta=rep(1/13,13), phi=.2,
        sizes=list( n.wtsc = apply(counts$`WT-SC`,2,sum),
                    n.wtmc = apply(counts$`WT-MC`,2,sum),
                    n.mtmc = apply(counts$`MT-MC`,2,sum),
                    n.mtsc = apply(counts$`MT-SC`,2,sum),
                    nsurvive = nsurvive  ) ,
        mcmc=list( phi.init=1, phi.delta=.1, nsave=10, nskip=10, initc=2 ) )


## Results of a longer (more realistic) simulation were `precooked' and
## are in the precooked data set as `simulatedPvalues'
data(precooked)


}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ ~kwd1 }
\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
